@@ -25,7 +25,8 @@ FILTER_REAL = 'live'
 FILTER_PRACTICE = 'demo'
 
 URL_LOGIN = 'https://www.trading212.com/login'
-URL_HOME = 'https://{}.trading212.com'
+URL_HOME_BASE = 'https://{}.trading212.com'
+URL_HOME = URL_HOME_BASE
 
 # declaration of processes
 
@@ -33,7 +34,11 @@ process_portfolio = [
 	{'class_name':'home-icon', 'action':'click', 'sleep':PAGELOAD_TO, 'filter':FILTER_PRACTICE},
 	{'class_name':'positions-table-item', 'action':'foreach', 'filter':FILTER_PRACTICE, 'action_parameters':[
 		{'class_name':'instrument-name', 'action':'store_text', 'action_parameters':'name'},
-		{'class_name':'quantity', 'action':'store_text', 'action_parameters':'shares'}
+		{'class_name':'quantity', 'action':'store_text', 'action_parameters':'shares'},
+		{'class_name':'instrument-name', 'action':'click', 'sleep':PAGELOAD_TO},
+		{'class_name':'quantity-and-price', 'action':'store_text', 'action_parameters':'quantity_and_price_full', 'context':'whole_page'},
+		{'class_name':'formatted-price', 'action':'store_text', 'action_parameters':'value'},
+		{'class_name':'position-result', 'action':'store_text', 'action_parameters':'return_value', 'context':'whole_page'},
 	]},
 	{'class_name':'portfolio-icon', 'action':'click', 'sleep':PAGELOAD_TO, 'filter':FILTER_REAL},
 	{'class_name':'investment-item', 'action':'foreach', 'filter':FILTER_REAL, 'action_parameters':[
@@ -98,12 +103,12 @@ def checkfilterpassed(f):
 # function to enable real/live mode
 def enable_real_mode():
 	global URL_HOME
-	URL_HOME = URL_HOME.format(FILTER_REAL)
+	URL_HOME = URL_HOME_BASE.format(FILTER_REAL)
 
 # function to enable practice/demo mode
 def enable_practice_mode():
 	global URL_HOME, PAGELOAD_TO, PAGEJS_TO
-	URL_HOME = URL_HOME.format(FILTER_PRACTICE)
+	URL_HOME = URL_HOME_BASE.format(FILTER_PRACTICE)
 	PAGELOAD_TO *= 3
 	PAGEJS_TO *= 3
 
@@ -135,12 +140,22 @@ def get_portfolio(brw):
 	# processing output for better presentation
 	portfolio = portfolio.get('list')
 	for i in range(0, len(portfolio)):
-		portfolio[i]['valuta'] = portfolio[i].get('value')[0]
-		portfolio[i]['value'] = float(portfolio[i].get('value')[1:].replace(',', ''))
-		portfolio[i]['shares'] = float(portfolio[i].get('shares').split(' ')[0].replace(',', ''))
-		portfolio[i]['return_percentage'] = float(portfolio[i].get('return').split('(')[1].split('%')[0])
-		portfolio[i]['return'] = portfolio[i].get('return').split(' ')[0][1:]
-	return portfolio
+		if portfolio[i].get('quantity_and_price_full') is None:
+			portfolio[i]['valuta'] = portfolio[i].get('value')[0]
+			portfolio[i]['value'] = portfolio[i].get('value')[1:]
+		else:
+			portfolio[i]['valuta'] = portfolio[i].get('quantity_and_price_full').split(' ')[2][0]
+			portfolio[i]['value'] = portfolio[i].get('quantity_and_price_full').split(' ')[2][1:]
+			del portfolio[i]['quantity_and_price_full']
+		portfolio[i]['value'] = float(portfolio[i].get('value').replace(',', ''))
+		if ' ' in portfolio[i].get('shares'): portfolio[i]['shares'] = float(portfolio[i].get('shares').split(' ')[0].replace(',', ''))
+		if not portfolio[i].get('return_value') is None:
+			portfolio[i]['return'] = '{} ({}%)'.format(portfolio[i].get('return_value'), float(float(portfolio[i].get('return_value')[1:]) / float(portfolio[i].get('value')) * 100))
+			del portfolio[i]['return_value']
+		if not portfolio[i].get('return') is None:
+			portfolio[i]['return_percentage'] = float(portfolio[i].get('return').split('(')[1].split('%')[0])
+		portfolio[i]['return'] = float(portfolio[i].get('return').split(' ')[0][1:])
+		return portfolio
 
 # buys a stock identified by its own ticket, specifying the amount to spent (in current valuta) and an optional maximum price
 def buy(brw, ticker, amount, max_price=None):
